@@ -3,16 +3,17 @@ use super::{
     event::Events,
     r#impl::{Cluster, ClusterStartError},
     scheme::ShardScheme,
+    ClusterStartErrorType,
 };
 use crate::{
-    shard::{LargeThresholdError, ResumeSession, ShardBuilder},
+    shard::{tls::TlsContainer, LargeThresholdError, ResumeSession, ShardBuilder},
     EventTypeFlags,
 };
 use std::{collections::HashMap, sync::Arc};
 use twilight_gateway_queue::{LocalQueue, Queue};
 use twilight_http::Client;
 use twilight_model::gateway::{
-    payload::{identify::IdentifyProperties, update_presence::UpdatePresencePayload},
+    payload::outgoing::{identify::IdentifyProperties, update_presence::UpdatePresencePayload},
     Intents,
 };
 
@@ -23,7 +24,7 @@ use twilight_model::gateway::{
 /// Create a cluster with only the `GUILD_MESSAGES` intents with a
 /// [`large_threshold`] of 100.
 ///
-/// ```rust,no_run
+/// ```no_run
 /// use std::env;
 /// use twilight_gateway::{Cluster, Intents};
 ///
@@ -44,25 +45,8 @@ pub struct ClusterBuilder(ClusterConfig, ShardBuilder);
 impl ClusterBuilder {
     /// Create a new builder to construct and configure a cluster.
     pub fn new(token: impl Into<String>, intents: Intents) -> Self {
-        Self::_new(token.into(), intents)
-    }
-
-    fn _new(mut token: String, intents: Intents) -> Self {
-        if !token.starts_with("Bot ") {
-            token.insert_str(0, "Bot ");
-        }
-
-        let token = token.into_boxed_str();
-
-        let http_client = Client::new(token.to_string());
-
-        let shard_config =
-            ShardBuilder::new(token.clone(), intents).http_client(http_client.clone());
-
         Self(
             ClusterConfig {
-                http_client,
-                shard_config: shard_config.0,
                 shard_scheme: ShardScheme::Auto,
                 queue: Arc::new(LocalQueue::new()),
                 resume_sessions: HashMap::new(),
@@ -80,6 +64,13 @@ impl ClusterBuilder {
     ///
     /// [`ClusterStartErrorType::RetrievingGatewayInfo`]: super::ClusterStartErrorType::RetrievingGatewayInfo
     pub async fn build(mut self) -> Result<(Cluster, Events), ClusterStartError> {
+        let tls = TlsContainer::new().map_err(|err| ClusterStartError {
+            kind: ClusterStartErrorType::Tls,
+            source: Some(Box::new(err)),
+        })?;
+
+        (self.1).0.tls = Some(tls);
+
         if (self.1).0.gateway_url.is_none() {
             let maybe_response = (self.1).0.http_client.gateway().authed().exec().await;
 
@@ -90,9 +81,7 @@ impl ClusterBuilder {
             }
         }
 
-        self.0.shard_config = (self.1).0;
-
-        Cluster::new_with_config(self.0).await
+        Cluster::new_with_config(self.0, self.1 .0).await
     }
 
     /// Set the event types to process.
@@ -124,7 +113,7 @@ impl ClusterBuilder {
     /// information.
     ///
     /// Defaults to a new, default HTTP client is used.
-    pub fn http_client(mut self, http_client: Client) -> Self {
+    pub fn http_client(mut self, http_client: Arc<Client>) -> Self {
         self.1 = self.1.http_client(http_client);
 
         self
@@ -143,7 +132,7 @@ impl ClusterBuilder {
     /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// use std::env::{self, consts::OS};
     /// use twilight_gateway::{Intents, Cluster};
-    /// use twilight_model::gateway::payload::identify::IdentifyProperties;
+    /// use twilight_model::gateway::payload::outgoing::identify::IdentifyProperties;
     ///
     /// let token = env::var("DISCORD_TOKEN")?;
     /// let properties = IdentifyProperties::new(
