@@ -8,7 +8,7 @@ use std::{
 use twilight_gateway_queue::{LocalQueue, Queue};
 use twilight_http::Client as HttpClient;
 use twilight_model::gateway::{
-    payload::{identify::IdentifyProperties, update_presence::UpdatePresencePayload},
+    payload::outgoing::{identify::IdentifyProperties, update_presence::UpdatePresencePayload},
     Intents,
 };
 
@@ -143,7 +143,7 @@ pub enum ShardIdErrorType {
 /// Create a new shard, setting the [`large_threshold`] to 100 and the
 /// [`shard`] ID to 5 out of 10:
 ///
-/// ```rust,no_run
+/// ```no_run
 /// use std::env;
 /// use twilight_gateway::{Intents, Shard};
 ///
@@ -160,7 +160,7 @@ pub enum ShardIdErrorType {
 /// [`ShardBuilder::new`]: Self::new
 /// [`large_threshold`]: Self::large_threshold
 /// [`shard`]: Self::shard
-#[derive(Clone, Debug)]
+#[derive(Debug)]
 pub struct ShardBuilder(pub(crate) Config);
 
 impl ShardBuilder {
@@ -179,16 +179,17 @@ impl ShardBuilder {
         Self(Config {
             event_types: EventTypeFlags::default(),
             gateway_url: None,
-            http_client: HttpClient::new(token.clone()),
+            http_client: Arc::new(HttpClient::new(token.clone())),
             identify_properties: None,
             intents,
-            large_threshold: 250,
+            large_threshold: 50,
             presence: None,
             queue: Arc::new(LocalQueue::new()),
             shard: [0, 1],
             token: token.into_boxed_str(),
             session_id: None,
             sequence: None,
+            tls: None,
         })
     }
 
@@ -223,7 +224,7 @@ impl ShardBuilder {
     ///
     /// Default is a new, unconfigured instance of an HTTP client.
     #[allow(clippy::missing_const_for_fn)]
-    pub fn http_client(mut self, http_client: HttpClient) -> Self {
+    pub fn http_client(mut self, http_client: Arc<HttpClient>) -> Self {
         self.0.http_client = http_client;
 
         self
@@ -242,7 +243,7 @@ impl ShardBuilder {
     /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// use std::env::{self, consts::OS};
     /// use twilight_gateway::{Intents, Shard};
-    /// use twilight_model::gateway::payload::identify::IdentifyProperties;
+    /// use twilight_model::gateway::payload::outgoing::identify::IdentifyProperties;
     ///
     /// let token = env::var("DISCORD_TOKEN")?;
     /// let properties = IdentifyProperties::new(
@@ -266,7 +267,7 @@ impl ShardBuilder {
 
     /// Set the maximum number of members in a guild to load the member list.
     ///
-    /// Default value is `250`. The minimum value is `50` and the maximum is
+    /// Default value is `50`. The minimum value is `50` and the maximum is
     /// `250`.
     ///
     /// # Examples
@@ -320,7 +321,7 @@ impl ShardBuilder {
     /// ```no_run
     /// use twilight_gateway::{Intents, Shard};
     /// use twilight_model::gateway::{
-    ///     payload::update_presence::UpdatePresencePayload,
+    ///     payload::outgoing::update_presence::UpdatePresencePayload,
     ///     presence::{ActivityType, MinimalActivity, Status},
     /// };
     ///
@@ -431,13 +432,7 @@ mod tests {
     assert_fields!(LargeThresholdErrorType::TooFew: value);
     assert_fields!(LargeThresholdErrorType::TooMany: value);
     assert_impl_all!(LargeThresholdError: Error, Send, Sync);
-    assert_impl_all!(
-        ShardBuilder: Clone,
-        Debug,
-        From<(String, Intents)>,
-        Send,
-        Sync
-    );
+    assert_impl_all!(ShardBuilder: Debug, From<(String, Intents)>, Send, Sync);
     assert_impl_all!(ShardIdErrorType: Debug, Send, Sync);
     assert_fields!(ShardIdErrorType::IdTooLarge: id, total);
     assert_impl_all!(ShardIdError: Error, Send, Sync);
